@@ -1,14 +1,16 @@
+/* vim: set sw=8 ts=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /**
  * ms-excel-xf.h: MS Excel support for Gnumeric
  *
  * Authors:
- *    Michael Meeks (michael@ximian.com)
  *    Jody Goldberg (jody@gnome.org)
+ *    Michael Meeks (michael@ximian.com)
  *
- * (C) 1998-2001 Michael Meeks, Jody Goldberg
+ * (C) 1998-2001 Michael Meeks
+ * (C) 2002-2005 Jody Goldberg
  **/
-#ifndef GNUMERIC_MS_EXCEL_XF_H
-#define GNUMERIC_MS_EXCEL_XF_H
+#ifndef GNM_MS_EXCEL_XF_H
+#define GNM_MS_EXCEL_XF_H
 
 #include "style.h"
 #include "style-border.h"
@@ -26,7 +28,7 @@
 typedef struct _BiffXFData {
 	guint16 font_idx;
 	guint16 format_idx;
-	GnmFormat *style_format;
+	GOFormat *style_format;
 	gboolean   is_simple_format;
 
 	gboolean hidden;
@@ -34,15 +36,15 @@ typedef struct _BiffXFData {
 	MsBiffXfType xftype;	/*  -- Very important field... */
 	MsBiffFormat format;
 	guint16 parentstyle;
-	StyleHAlignFlags halign;
-	StyleVAlignFlags valign;
+	GnmHAlign halign;
+	GnmVAlign valign;
 	gboolean wrap_text;
 	gboolean shrink_to_fit;
 	int rotation;
 	int indent;
 	GnmTextDir text_dir;
 	guint16 border_color[STYLE_ORIENT_MAX];
-	StyleBorderType border_type[STYLE_ORIENT_MAX];
+	GnmStyleBorderType border_type[STYLE_ORIENT_MAX];
 	guint16 fill_pattern_idx;
 	guint16 pat_foregnd_col;
 	guint16 pat_backgnd_col;
@@ -51,4 +53,4 @@ typedef struct _BiffXFData {
 	GnmStyle *mstyle;
 } BiffXFData;
 
-#endif
+#endif /* GNM_MS_EXCEL_XF_H */
