@@ -849,20 +849,31 @@ static GnmFuncHelp const help_text[] = {
 static GnmValue *
 gnumeric_text (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
-	GnmValue       *res, *match = NULL;
+	GnmValue *res, *match = NULL;
 	GnmValue const *v  = argv[0];
 	GOFormat *fmt;
 	GODateConventions const *conv =
 		workbook_date_conv (ei->pos->sheet->workbook);
+	GString *str;
+	GOFormatNumberError err;
 
+	/* Why do we have to do these here?  */
 	if (VALUE_IS_STRING (v)) {
 		match = format_match (value_peek_string (v), NULL, conv);
 		if (match != NULL)
 			v = match;
-	}
+	} else if (VALUE_IS_EMPTY (v))
+		v = value_zero;
+
 	fmt = go_format_new_from_XL (value_peek_string (argv[1]), TRUE);
-	res = value_new_string_nocopy (
-		format_value (fmt, v, NULL, -1, conv));
+	str = g_string_sized_new (80);
+	err = format_value_gstring (str, fmt, v, NULL, -1, conv);
+	if (err) {
+		g_string_free (str, TRUE);
+		res = value_new_error_VALUE (ei->pos);
+	} else {
+		res = value_new_string_nocopy (g_string_free (str, FALSE));
+	}
 	go_format_unref (fmt);
 
 	if (match != NULL)
