@@ -20,7 +20,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 
@@ -101,6 +101,8 @@ static struct {
 		N_("Simplex algorithm for Solver (LP Solve).") },
 	{ N_("Tom Dyas"),			GNM_FEATURE_HACKER,
 		N_("Original plugin engine.") },
+	{ N_("Kjell Eikland"),            GNM_ANALYTICS,
+	        N_("LP-solve") },
 	{ N_("Gergo Erdi"),			GNM_GUI,
 		N_("Custom UI tools") },
 	{ N_("John Gotts"),			GNM_PACKAGING,
@@ -115,8 +117,6 @@ static struct {
 		N_("Solver, lots of worksheet functions, and general trailblazer") },
 	{ N_("Jakub Jel\xc3\xadnek"),		GNM_CORE,
 		N_("One of the original core contributors") },
-	{ N_("Jakub Steiner"),		GNM_ART,
-		N_("Icons and Images") },
 	{ N_("Chris Lahey"),		GNM_FEATURE_HACKER,
 		N_("The original value format engine and libgoffice work") },
 	{ N_("Takashi Matsuda"),		GNM_FEATURE_HACKER,
@@ -127,6 +127,8 @@ static struct {
 		N_("SheetObject improvement") },
 	{ N_("Yukihiro Nakai"),             GNM_FEATURE_HACKER | GNM_TRANSLATION | GNM_QA,
 	        N_("Support for non-Latin languages") },
+	{ N_("Peter Notebaert"),            GNM_ANALYTICS,
+	        N_("LP-solve") },
 	{ N_("Emmanuel Pacaud"),		GNM_CORE | GNM_FEATURE_HACKER,
 		N_("Many plot types for charting engine.") },
 	{ N_("Federico M. Quintero"),	GNM_CORE,
@@ -139,6 +141,8 @@ static struct {
 		N_("original CSV support, French localization") },
 	{ N_("Ariel Rios"),			GNM_SCRIPTING,
 		N_("Guile support") },
+	{ N_("Jakub Steiner"),		GNM_ART,
+		N_("Icons and Images") },
 	{ N_("Uwe Steinmann"),		GNM_FEATURE_HACKER|GNM_IMPORT_EXPORT,
 		N_("Paradox Importer") },
 	{ N_("Arturo Tena"),		GNM_IMPORT_EXPORT,
@@ -371,7 +375,7 @@ dialog_about (WorkbookControlGUI *wbcg)
 	gog_dataset_set_dim (GOG_DATASET (tmp), 0,
 		go_data_scalar_str_new (
 			"Gnumeric " GNUMERIC_VERSION "\n"
-			"Copyright \xc2\xa9 2001-2004 Jody Goldberg\n"
+			"Copyright \xc2\xa9 2001-2006 Jody Goldberg\n"
 			"Copyright \xc2\xa9 1998-2000 Miguel de Icaza", FALSE),
 		NULL);
 	gog_style_set_font_desc (GOG_STYLED_OBJECT (tmp)->style,
