@@ -393,10 +393,11 @@ name_guru_add (NameGuruState *state)
 	if (!state->action_possible)
 		return TRUE;
 
-	name  = gtk_entry_get_text (state->name);
-
-	g_return_val_if_fail (name != NULL, TRUE);
-	g_return_val_if_fail (name[0] != '\0', TRUE);
+	name = gtk_entry_get_text (state->name);
+	if (name[0] == 0) {
+		/* Empty name -- probably ok/close after add.  */
+		return TRUE;
+	}
 
 	texpr = gnm_expr_entry_parse (state->expr_entry,
 		&state->pp, parse_error_init (&perr), FALSE, GNM_EXPR_PARSE_DEFAULT);
@@ -419,7 +420,7 @@ name_guru_add (NameGuruState *state)
 			_("Why would you want to define a name to be #NAME?"));
 		gtk_widget_grab_focus (GTK_WIDGET (state->expr_entry));
 		parse_error_free (&perr);
-		/* FIXME: Probable leak.  */
+		gnm_expr_top_unref (texpr);
 		return FALSE;
 	}
 
