@@ -367,24 +367,26 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 
 /**
  * sheet_object_clear_sheet :
- * @so :
+ * @so : #SheetObject
  *
  * Removes @so from it's container, unrealizes all views, disconects the
  * associated data and unrefs the object
- *
- * Returns TRUE if there was a problem
  **/
-gboolean
+void
 sheet_object_clear_sheet (SheetObject *so)
 {
 	GSList *ptr;
 	gpointer view_handler;
 
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), TRUE);
-	g_return_val_if_fail (IS_SHEET (so->sheet), TRUE);
+	g_return_if_fail (IS_SHEET_OBJECT (so));
+
+	if (so->sheet == NULL) /* already removed */
+		return;
+
+	g_return_if_fail (IS_SHEET (so->sheet));
 
 	ptr = g_slist_find (so->sheet->sheet_objects, so);
-	g_return_val_if_fail (ptr != NULL, TRUE);
+	g_return_if_fail (ptr != NULL);
 
 	/* clear any pending attempts to create views */
 	view_handler = g_object_get_data (G_OBJECT (so), "create_view_handler");
@@ -400,7 +402,7 @@ sheet_object_clear_sheet (SheetObject *so)
 
 	if (SO_CLASS (so)->remove_from_sheet &&
 	    SO_CLASS (so)->remove_from_sheet (so))
-		return TRUE;
+		return;
 
 	so->sheet->sheet_objects = g_slist_remove_link (so->sheet->sheet_objects, ptr);
 	g_slist_free (ptr);
@@ -411,8 +413,6 @@ sheet_object_clear_sheet (SheetObject *so)
 
 	so->sheet = NULL;
 	g_object_unref (G_OBJECT (so));
-
-	return FALSE;
 }
 
 void
@@ -450,6 +450,9 @@ sheet_object_new_view (SheetObject *so, SheetObjectViewContainer *container)
 
 	view = SO_CLASS (so)->new_view (so, container);
 
+	if (NULL == view)
+		return NULL;
+
 	g_return_val_if_fail (IS_SHEET_OBJECT_VIEW (view), NULL);
 
 	/* Store some useful information */
@@ -513,9 +516,6 @@ sheet_object_draw_cairo (SheetObject const *so, gpointer *data)
 		case SO_ANCHOR_PERCENTAGE_FROM_COLROW_START:
 			x = cell_width * anchor->offset[0];
 			break;
-		case SO_ANCHOR_PERCENTAGE_FROM_COLROW_END:
-			x = cell_width * (1. - anchor->offset[0]);
-			break;
 		case SO_ANCHOR_PTS_FROM_COLROW_START:
 			x = anchor->offset[0];
 			break;
@@ -531,9 +531,6 @@ sheet_object_draw_cairo (SheetObject const *so, gpointer *data)
 		case SO_ANCHOR_PERCENTAGE_FROM_COLROW_START:
 			y = cell_height * anchor->offset[1];
 			break;
-		case SO_ANCHOR_PERCENTAGE_FROM_COLROW_END:
-			y = cell_height * (1 - anchor->offset[1]);
-			break;
 		case SO_ANCHOR_PTS_FROM_COLROW_START:
 			y = anchor->offset[1];
 			break;
@@ -555,9 +552,6 @@ sheet_object_draw_cairo (SheetObject const *so, gpointer *data)
 		case SO_ANCHOR_PERCENTAGE_FROM_COLROW_START:
 			width -= cell_width * (1. - anchor->offset[2]);
 			break;
-		case SO_ANCHOR_PERCENTAGE_FROM_COLROW_END:
-			width -= cell_width * anchor->offset[2];
-			break;
 		case SO_ANCHOR_PTS_FROM_COLROW_START:
 			width -= cell_width - anchor->offset[2];
 			break;
@@ -575,9 +569,6 @@ sheet_object_draw_cairo (SheetObject const *so, gpointer *data)
 		case SO_ANCHOR_PERCENTAGE_FROM_COLROW_START:
 			height -= cell_height * (1 - anchor->offset[3]);
 			break;
-		case SO_ANCHOR_PERCENTAGE_FROM_COLROW_END:
-			height -= cell_height * anchor->offset[3];
-			break;
 		case SO_ANCHOR_PTS_FROM_COLROW_START:
 			height -= cell_height - anchor->offset[3];
 			break;
@@ -640,8 +631,6 @@ cell_offset_calc_pt (Sheet const *sheet, int i, gboolean is_col,
 {
 	ColRowInfo const *cri = sheet_colrow_get_info (sheet, i, is_col);
 	/* TODO : handle other anchor types */
-	if (anchor_type == SO_ANCHOR_PERCENTAGE_FROM_COLROW_END)
-		return (1. - offset) * cri->size_pts;
 	return offset * cri->size_pts;
 }
 
@@ -876,7 +865,7 @@ sheet_object_dup (SheetObject const *so)
 
 
 /**
- * sheet_object_clone_sheet:
+ * sheet_objects_dup:
  * @src: The source sheet to read the objects from
  * @dst: The destination sheet to attach the objects to
  * @range: Optionally NULL region of interest
@@ -884,7 +873,7 @@ sheet_object_dup (SheetObject const *so)
  * Clones the objects of the src sheet and attaches them into the dst sheet
  **/
 void
-sheet_object_clone_sheet (Sheet const *src, Sheet *dst, GnmRange *range)
+sheet_objects_dup (Sheet const *src, Sheet *dst, GnmRange *range)
 {
 	SheetObject *so;
 	SheetObject *new_so;
