@@ -230,8 +230,8 @@ main (int argc, char **argv)
 	}
 
 	if (ssindex_show_version) {
-		g_print (_("ssindex version '%s'\ndatadir := '%s'\nlibdir := '%s'\n"),
-			 GNUMERIC_VERSION, gnm_sys_data_dir (), gnm_sys_lib_dir ());
+		g_printerr (_("ssindex version '%s'\ndatadir := '%s'\nlibdir := '%s'\n"),
+			    GNUMERIC_VERSION, gnm_sys_data_dir (), gnm_sys_lib_dir ());
 		return 0;
 	} else if (!ssindex_run_indexer && !ssindex_list_mime_types) {
 		g_printerr (_("Usage: %s [OPTION...] %s\n"),
@@ -256,13 +256,12 @@ main (int argc, char **argv)
 		for (i = 1; i < argc; i++) {
 			char const *file = argv[i];
 			gnm_io_context_processing_file (ioc, file);
-			g_print ("-> %s\n", file);
 			res |= ssindex (file, ioc);
 		}
 		g_object_unref (ioc);
 	} else if (ssindex_list_mime_types) {
 		GList *o;
-		for (o = get_file_openers (); o != NULL ; o = o->next) {
+		for (o = go_get_file_openers (); o != NULL ; o = o->next) {
 			GSList const *mime = go_file_opener_get_mimes (o->data);
 			for (; mime != NULL ; mime = mime->next)
 				g_print ("%s\n", (char const *)mime->data);
