@@ -11,6 +11,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <goffice/utils/go-glib-extras.h>
 
 #ifndef USE_STRING_POOLS
 #define USE_STRING_POOLS 1
@@ -18,9 +19,9 @@
 
 #if USE_STRING_POOLS
 /* Memory pool for strings.  */
-static GnmMemChunk *string_pool;
-#define CHUNK_ALLOC(T,p) ((T*)gnm_mem_chunk_alloc (p))
-#define CHUNK_FREE(p,v) gnm_mem_chunk_free ((p), (v))
+static GOMemChunk *string_pool;
+#define CHUNK_ALLOC(T,p) ((T*)go_mem_chunk_alloc (p))
+#define CHUNK_FREE(p,v) go_mem_chunk_free ((p), (v))
 #else
 #define CHUNK_ALLOC(T,c) g_new (T,1)
 #define CHUNK_FREE(p,v) g_free ((v))
@@ -103,13 +104,59 @@ gnm_string_unref (GnmString *string)
 	}
 }
 
+static void
+cb_collect_strings (G_GNUC_UNUSED gpointer key, gpointer str,
+		    gpointer user_data)
+{
+	GSList **pstrs = user_data;
+	*pstrs = g_slist_prepend (*pstrs, str);
+}
+
+static gint
+cb_by_refcount_str (gconstpointer a_, gconstpointer b_)
+{
+	const GnmString *a = a_;
+	const GnmString *b = b_;
+
+	if (a->ref_count == b->ref_count)
+		return strcmp (a->str, b->str);
+	return (a->ref_count - b->ref_count);
+}
+
+void
+gnm_string_dump (void)
+{
+	GSList *strs = NULL;
+	GSList *l;
+	int refs = 0, len = 0;
+	int count;
+
+	g_hash_table_foreach (string_hash_table, cb_collect_strings, &strs);
+	strs = g_slist_sort (strs, cb_by_refcount_str);
+	count = g_slist_length (strs);
+	for (l = strs; l; l = l->next) {
+		const GnmString *s = l->data;
+		refs += s->ref_count;
+		len += strlen (s->str);
+	}
+
+	for (l = g_slist_nth (strs, MAX (0, count - 100)); l; l = l->next) {
+		const GnmString *s = l->data;
+		g_print ("%8d \"%s\"\n", s->ref_count, s->str);
+	}
+	g_print ("String table contains %d different strings.\n", count);
+	g_print ("String table contains a total of %d characters.\n", len);
+	g_print ("String table contains a total of %d refs.\n", refs);
+	g_slist_free (strs);
+}
+
 void
 gnm_string_init (void)
 {
 	string_hash_table = g_hash_table_new (g_str_hash, g_str_equal);
 #if USE_STRING_POOLS
 	string_pool =
-		gnm_mem_chunk_new ("string pool",
+		go_mem_chunk_new ("string pool",
 				   sizeof (GnmString),
 				   16 * 1024 - 128);
 #endif
@@ -131,8 +178,8 @@ gnm_string_shutdown (void)
 	g_hash_table_destroy (string_hash_table);
 	string_hash_table = NULL;
 #if USE_STRING_POOLS
-	gnm_mem_chunk_foreach_leak (string_pool, cb_string_pool_leak, NULL);
-	gnm_mem_chunk_destroy (string_pool, FALSE);
+	go_mem_chunk_foreach_leak (string_pool, cb_string_pool_leak, NULL);
+	go_mem_chunk_destroy (string_pool, FALSE);
 	string_pool = NULL;
 #endif
 }
