@@ -2,7 +2,7 @@
  * goal-seek.c:  A generic root finder.
  *
  * Author:
- *   Morten Welinder (terra@diku.dk)
+ *   Morten Welinder (terra@gnome.org)
  *
  */
 
@@ -21,9 +21,6 @@
 #include <math.h>
 #include <limits.h>
 
-#ifdef DEBUG_GOAL_SEEK
-#include <stdio.h>
-#endif
 
 static gboolean
 update_data (gnm_float x, gnm_float y, GoalSeekData *data)
@@ -33,7 +30,7 @@ update_data (gnm_float x, gnm_float y, GoalSeekData *data)
 			if (data->havexneg) {
 				/*
 				 * When we have pos and neg, prefer the new point only
-				 * if it makes the pos-neg x-internal smaller.
+				 * if it makes the pos-neg x-interval smaller.
 				 */
 				if (gnm_abs (x - data->xneg) < gnm_abs (data->xpos - data->xneg)) {
 					data->xpos = x;
@@ -55,7 +52,7 @@ update_data (gnm_float x, gnm_float y, GoalSeekData *data)
 			if (data->havexpos) {
 				/*
 				 * When we have pos and neg, prefer the new point only
-				 * if it makes the pos-neg x-internal smaller.
+				 * if it makes the pos-neg x-interval smaller.
 				 */
 				if (gnm_abs (x - data->xpos) < gnm_abs (data->xpos - data->xneg)) {
 					data->xneg = x;
@@ -77,6 +74,9 @@ update_data (gnm_float x, gnm_float y, GoalSeekData *data)
 		/* Lucky guess...  */
 		data->have_root = TRUE;
 		data->root = x;
+#ifdef DEBUG_GOAL_SEEK
+		g_print ("update_data: got root %.20" GNM_FORMAT_g "\n", x);
+#endif
 		return TRUE;
 	}
 }
@@ -94,7 +94,7 @@ fake_df (GoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
 	GoalSeekStatus status;
 
 #ifdef DEBUG_GOAL_SEEK
-	printf ("fake_df (x=%.20" GNM_FORMAT_g ", xstep=%.20" GNM_FORMAT_g ")\n",
+	g_print ("fake_df (x=%.20" GNM_FORMAT_g ", xstep=%.20" GNM_FORMAT_g ")\n",
 		x, xstep);
 #endif
 
@@ -108,7 +108,7 @@ fake_df (GoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
 
 	if (xl == xr) {
 #ifdef DEBUG_GOAL_SEEK
-		printf ("==> xl == xr\n");
+		g_print ("==> xl == xr\n");
 #endif
 		return GOAL_SEEK_ERROR;
 	}
@@ -116,30 +116,30 @@ fake_df (GoalSeekFunction f, gnm_float x, gnm_float *dfx, gnm_float xstep,
 	status = f (xl, &yl, user_data);
 	if (status != GOAL_SEEK_OK) {
 #ifdef DEBUG_GOAL_SEEK
-		printf ("==> failure at xl\n");
+		g_print ("==> failure at xl\n");
 #endif
 		return status;
 	}
 #ifdef DEBUG_GOAL_SEEK
-	printf ("==> xl=%.20" GNM_FORMAT_g "; yl=%.20" GNM_FORMAT_g "\n",
-		xl, yl);
+	g_print ("==> xl=%.20" GNM_FORMAT_g "; yl=%.20" GNM_FORMAT_g "\n",
+		 xl, yl);
 #endif
 
 	status = f (xr, &yr, user_data);
 	if (status != GOAL_SEEK_OK) {
 #ifdef DEBUG_GOAL_SEEK
-		printf ("==> failure at xr\n");
+		g_print ("==> failure at xr\n");
 #endif
 		return status;
 	}
 #ifdef DEBUG_GOAL_SEEK
-	printf ("==> xr=%.20" GNM_FORMAT_g "; yr=%.20" GNM_FORMAT_g "\n",
-		xr, yr);
+	g_print ("==> xr=%.20" GNM_FORMAT_g "; yr=%.20" GNM_FORMAT_g "\n",
+		 xr, yr);
 #endif
 
 	*dfx = (yr - yl) / (xr - xl);
 #ifdef DEBUG_GOAL_SEEK
-	printf ("==> %.20" GNM_FORMAT_g "\n", *dfx);
+	g_print ("==> %.20" GNM_FORMAT_g "\n", *dfx);
 #endif
 	return gnm_finite (*dfx) ? GOAL_SEEK_OK : GOAL_SEEK_ERROR;
 }
@@ -169,6 +169,10 @@ goal_seek_point (GoalSeekFunction f, GoalSeekData *data,
 	if (data->have_root)
 		return GOAL_SEEK_OK;
 
+#ifdef DEBUG_GOAL_SEEK
+	g_print ("goal_seek_point\n");
+#endif
+
 	if (x0 < data->xmin || x0 > data->xmax)
 		return GOAL_SEEK_ERROR;
 
@@ -183,6 +187,101 @@ goal_seek_point (GoalSeekFunction f, GoalSeekData *data,
 }
 
 
+static GoalSeekStatus
+goal_seek_newton_polish (GoalSeekFunction f, GoalSeekFunction df,
+			 GoalSeekData *data, void *user_data,
+			 gnm_float x0, gnm_float y0)
+{
+	int iterations;
+	gnm_float last_df0 = 1;
+	gboolean try_newton = TRUE;
+	gboolean try_square = x0 != 0 && gnm_abs (x0) < 1e10;
+
+#ifdef DEBUG_GOAL_SEEK
+	g_print ("goal_seek_newton_polish\n");
+#endif
+
+	for (iterations = 0; iterations < 20; iterations++) {
+		if (try_square) {
+			double x1 = x0 * gnm_abs (x0);
+			double y1, r;
+			GoalSeekStatus status = f (x1, &y1, user_data);
+			if (status != GOAL_SEEK_OK)
+				goto nomore_square;
+
+			if (update_data (x1, y1, data))
+				return GOAL_SEEK_OK;
+
+			r = gnm_abs (y1 / y0);
+			if (r >= 1)
+				goto nomore_square;
+
+			x0 = x1;
+#ifdef DEBUG_GOAL_SEEK	
+			g_print ("polish square: x0=%.20" GNM_FORMAT_g "\n",
+				 x0);
+#endif
+			if (r > 0.5)
+				goto nomore_square;
+
+			continue;
+
+		nomore_square:
+			try_square = FALSE;
+		}
+
+		if (try_newton) {
+			double df0, r, x1, y1;
+			GoalSeekStatus status = df
+				? df (x0, &df0, user_data)
+				: fake_df (f, x0, &df0, gnm_abs (x0) / 1e6, data, user_data);
+			if (status != GOAL_SEEK_OK || df0 == 0)
+				df0 = last_df0;  /* Bogus */
+			else
+				last_df0 = df0;
+
+			x1 = x0 - y0 / df0;
+			if (x1 < data->xmin || x1 > data->xmax)
+				goto nomore_newton;
+
+			status = f (x1, &y1, user_data);
+			if (status != GOAL_SEEK_OK)
+				goto nomore_newton;
+
+			if (update_data (x1, y1, data))
+				return GOAL_SEEK_OK;
+
+			r = gnm_abs (y1 / y0);
+			if (r >= 1)
+				goto nomore_newton;
+
+			x0 = x1;
+#ifdef DEBUG_GOAL_SEEK	
+			g_print ("polish Newton: x0=%.20" GNM_FORMAT_g "\n",
+				 x0);
+#endif
+			if (r > 0.5)
+				goto nomore_newton;
+
+			continue;
+
+		nomore_newton:
+			try_newton = FALSE;
+		}
+
+		/* Nothing left to try.  */
+		break;
+	}
+
+	if (goal_seek_bisection (f, data, user_data) == GOAL_SEEK_OK)
+		return GOAL_SEEK_OK;
+
+	data->root = x0;
+	data->have_root = TRUE;
+	return GOAL_SEEK_OK;
+}
+
+
 /*
  * Seek a goal (root) using Newton's iterative method.
  *
@@ -201,17 +300,24 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 {
 	int iterations;
 	gnm_float precision = data->precision / 2;
+	gnm_float last_df0 = 1;
+	gnm_float step_factor = 1e-6;
 
 	if (data->have_root)
 		return GOAL_SEEK_OK;
 
 #ifdef DEBUG_GOAL_SEEK
-	printf ("goal_seek_newton\n");
+	g_print ("goal_seek_newton\n");
 #endif
 
-	for (iterations = 0; iterations < 20; iterations++) {
+	for (iterations = 0; iterations < 100; iterations++) {
 		gnm_float x1, y0, df0, stepsize;
 		GoalSeekStatus status;
+		gboolean flat;
+
+#ifdef DEBUG_GOAL_SEEK	
+		g_print ("x0 = %.20" GNM_FORMAT_g "   (i=%d)\n", x0, iterations);
+#endif
 
 		/* Check whether we have left the valid interval.  */
 		if (x0 < data->xmin || x0 > data->xmax)
@@ -222,8 +328,7 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 			return status;
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("x0 = %.20" GNM_FORMAT_g "\n", x0);
-		printf ("                                        y0 = %.20" GNM_FORMAT_g "\n", y0);
+		g_print ("                                        y0 = %.20" GNM_FORMAT_g "\n", y0);
 #endif
 
 		if (update_data (x0, y0, data))
@@ -240,7 +345,7 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 				else
 					xstep = (data->xmax - data->xmin) / 1e6;
 			else
-				xstep = gnm_abs (x0) / 1e6;
+				xstep = step_factor * gnm_abs (x0);
 
 			status = fake_df (f, x0, &df0, xstep, data, user_data);
 		}
@@ -248,28 +353,61 @@ goal_seek_newton (GoalSeekFunction f, GoalSeekFunction df,
 			return status;
 
 		/* If we hit a flat spot, we are in trouble.  */
-		if (df0 == 0)
-			return GOAL_SEEK_ERROR;
+		flat = (df0 == 0);
+		if (flat) {
+			last_df0 /= 2;
+			if (gnm_abs (last_df0) <= GNM_MIN)
+				return GOAL_SEEK_ERROR;
+			df0 = last_df0;  /* Might be utterly bogus.  */
+		} else
+			last_df0 = df0;
+
+		if (data->havexpos && data->havexneg)
+			x1 = x0 - y0 / df0;
+		else
+			/*
+			 * Overshoot slightly to prevent us from staying on
+			 * just one side of the root.
+			 */
+			x1 = x0 - 1.000001 * y0 / df0;
 
-		/*
-		 * Overshoot slightly to prevent us from staying on
-		 * just one side of the root.
-		 */
-		x1 = x0 - 1.000001 * y0 / df0;
 		stepsize = gnm_abs (x1 - x0) / (gnm_abs (x0) + gnm_abs (x1));
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("                                        df0 = %.20" GNM_FORMAT_g "\n", df0);
-		printf ("                                        ss = %.20" GNM_FORMAT_g "\n", stepsize);
+		g_print ("                                        df0 = %.20" GNM_FORMAT_g "\n", df0);
+		g_print ("                                        ss = %.20" GNM_FORMAT_g "\n", stepsize);
 #endif
 
-		x0 = x1;
-
 		if (stepsize < precision) {
-			data->root = x0;
-			data->have_root = TRUE;
+			goal_seek_newton_polish (f, df, data, user_data, x0, y0);
 			return GOAL_SEEK_OK;
 		}
+
+		if (flat && iterations > 0) {
+			/*
+			 * Verify that we made progress using our
+			 * potentially bogus df0.
+			 */
+			double y1;
+
+			if (x1 < data->xmin || x1 > data->xmax)
+				return GOAL_SEEK_ERROR;
+
+			status = f (x1, &y1, user_data);
+			if (status != GOAL_SEEK_OK)
+				return status;
+
+#ifdef DEBUG_GOAL_SEEK
+			g_print ("                                        y1 = %.20" GNM_FORMAT_g "\n", y1);
+#endif
+			if (gnm_abs (y1) >= 0.9 * gnm_abs (y0))
+				return GOAL_SEEK_ERROR;
+		}
+
+		if (stepsize < step_factor)
+			step_factor = stepsize;
+
+		x0 = x1;
 	}
 
 	return GOAL_SEEK_ERROR;
@@ -302,7 +440,7 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 		return GOAL_SEEK_OK;
 
 #ifdef DEBUG_GOAL_SEEK
-	printf ("goal_seek_bisection\n");
+	g_print ("goal_seek_bisection\n");
 #endif
 
 	if (!data->havexpos || !data->havexneg)
@@ -394,13 +532,16 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 			 * just one side of the root.
 			 */
 			xmid = x0 - 1.01 * y0 / df0;
-			if ((xmid < data->xpos && xmid < data->xneg) ||
-			    (xmid > data->xpos && xmid > data->xneg))
-				/* We left the interval.  */
-				continue;
 		}
 		}
 
+		if ((xmid < data->xpos && xmid < data->xneg) ||
+		    (xmid > data->xpos && xmid > data->xneg)) {
+			/* We left the interval.  */
+			xmid = (data->xpos + data->xneg) / 2;
+			method = M_MIDPOINT;
+		}
+
 		status = f (xmid, &ymid, user_data);
 		if (status != GOAL_SEEK_OK)
 			continue;
@@ -416,8 +557,8 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 			default: themethod = "?";
 			}
 
-			printf ("xmid = %.20" GNM_FORMAT_g " (%s)\n", xmid, themethod);
-			printf ("                                        ymid = %.20" GNM_FORMAT_g "\n", ymid);
+			g_print ("xmid = %.20" GNM_FORMAT_g " (%s)\n", xmid, themethod);
+			g_print ("                                        ymid = %.20" GNM_FORMAT_g "\n", ymid);
 		}
 #endif
 
@@ -429,10 +570,10 @@ goal_seek_bisection (GoalSeekFunction f, GoalSeekData *data, void *user_data)
 			/ (gnm_abs (data->xpos) + gnm_abs (data->xneg));
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("                                          ss = %.20" GNM_FORMAT_g "\n", stepsize);
+		g_print ("                                          ss = %.20" GNM_FORMAT_g "\n", stepsize);
 #endif
 
-		if (stepsize < data->precision) {
+		if (stepsize < GNM_EPSILON) {
 			if (data->yneg < ymid)
 				ymid = data->yneg, xmid = data->xneg;
 
@@ -461,6 +602,10 @@ goal_seek_trawl_uniformly (GoalSeekFunction f,
 	if (data->have_root)
 		return GOAL_SEEK_OK;
 
+#ifdef DEBUG_GOAL_SEEK
+	g_print ("goal_seek_trawl_uniformly\n");
+#endif
+
 	if (xmin > xmax || xmin < data->xmin || xmax > data->xmax)
 		return GOAL_SEEK_ERROR;
 
@@ -478,8 +623,8 @@ goal_seek_trawl_uniformly (GoalSeekFunction f,
 			continue;
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("x = %.20" GNM_FORMAT_g "\n", x);
-		printf ("                                        y = %.20" GNM_FORMAT_g "\n", y);
+		g_print ("x = %.20" GNM_FORMAT_g "\n", x);
+		g_print ("                                        y = %.20" GNM_FORMAT_g "\n", y);
 #endif
 
 		if (update_data (x, y, data))
@@ -502,6 +647,10 @@ goal_seek_trawl_normally (GoalSeekFunction f,
 	if (data->have_root)
 		return GOAL_SEEK_OK;
 
+#ifdef DEBUG_GOAL_SEEK
+	g_print ("goal_seek_trawl_normally\n");
+#endif
+
 	if (sigma <= 0 || mu < data->xmin || mu > data->xmax)
 		return GOAL_SEEK_ERROR;
 
@@ -522,8 +671,8 @@ goal_seek_trawl_normally (GoalSeekFunction f,
 			continue;
 
 #ifdef DEBUG_GOAL_SEEK
-		printf ("x = %.20" GNM_FORMAT_g "\n", x);
-		printf ("                                        y = %.20" GNM_FORMAT_g "\n", y);
+		g_print ("x = %.20" GNM_FORMAT_g "\n", x);
+		g_print ("                                        y = %.20" GNM_FORMAT_g "\n", y);
 #endif
 
 		if (update_data (x, y, data))
