@@ -423,17 +423,17 @@ value_parse_boolean (char const *str, gboolean translated)
 {
 	if (translated) {
 		/* FIXME: ascii???  */
-		if (0 == g_ascii_strcasecmp (str, format_boolean (TRUE)))
-			return TRUE;
-		else if (0 == g_ascii_strcasecmp (str, format_boolean (FALSE)))
-			return FALSE;
+		if (0 == g_ascii_strcasecmp (str, go_format_boolean (TRUE)))
+			return +TRUE;
+		else if (0 == g_ascii_strcasecmp (str, go_format_boolean (FALSE)))
+			return +FALSE;
 		else
 			return -1;
 	} else {
 		if (0 == g_ascii_strcasecmp (str, "TRUE"))
-			return TRUE;
+			return +TRUE;
 		else if (0 == g_ascii_strcasecmp (str, "FALSE"))
-			return FALSE;
+			return +FALSE;
 		else
 			return -1;
 	}
@@ -844,7 +844,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		gboolean b = v->v_bool.val;
 		g_string_append (target,
 				 conv->output_translated
-				 ? format_boolean (b)
+				 ? go_format_boolean (b)
 				 : (b ? "TRUE" : "FALSE"));
 		return;
 	}
@@ -866,7 +866,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		if (conv->output_array_row_sep)
 			row_sep = conv->output_array_row_sep;
 		else {
-			locale_row_sep[0] = format_get_row_sep ();
+			locale_row_sep[0] = go_format_get_row_sep ();
 			locale_row_sep[1] = 0;
 			row_sep = locale_row_sep;
 		}
@@ -874,7 +874,7 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 		if (conv->output_array_col_sep)
 			col_sep = conv->output_array_col_sep;
 		else {
-			locale_col_sep[0] = format_get_col_sep ();
+			locale_col_sep[0] = go_format_get_col_sep ();
 			locale_col_sep[1] = 0;
 			col_sep = locale_col_sep;
 		}
@@ -1689,6 +1689,19 @@ filter_row:
 
 /****************************************************************************/
 
+GType
+gnm_value_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0)
+		t = g_boxed_type_register_static ("GnmValue",
+			 (GBoxedCopyFunc)value_dup,
+			 (GBoxedFreeFunc)value_release);
+	return t;
+}
+/****************************************************************************/
+
 GnmValueErr const value_terminate_err = { VALUE_ERROR, NULL, NULL };
 static GnmValueFloat const the_value_zero = { VALUE_FLOAT, NULL, 0 };
 GnmValue const *value_zero = (GnmValue const *)&the_value_zero;
