@@ -20,17 +20,13 @@ WorkbookControl *wb_control_wrapper_new (WorkbookControl *wbc,
 					 WorkbookView *wbv, Workbook *wb,
 					 void *extra);
 
-void wb_control_update_title	     (WorkbookControl *wbc);
 void wb_control_style_feedback	     (WorkbookControl *wbc, GnmStyle const *changes);
 void wb_control_edit_line_set        (WorkbookControl *wbc, char const *text);
 void wb_control_selection_descr_set  (WorkbookControl *wbc, char const *text);
-void wb_control_auto_expr_value	     (WorkbookControl *wbc);
 
 void wb_control_sheet_add	     (WorkbookControl *wbc, SheetView *sv);
 void wb_control_sheet_remove	     (WorkbookControl *wbc, Sheet *sheet);
 void wb_control_sheet_focus	     (WorkbookControl *wbc, Sheet *sheet);
-void wb_control_sheet_move	     (WorkbookControl *wbc, Sheet *sheet,
-				      int old_pos);
 void wb_control_sheet_remove_all     (WorkbookControl *wbc);
 
 void wb_control_undo_redo_truncate   (WorkbookControl *wbc, int n, gboolean is_undo);
@@ -74,7 +70,8 @@ void wb_control_paste_from_selection (WorkbookControl *wbc,
 gboolean wb_control_claim_selection  (WorkbookControl *wbc);
 
 WorkbookView *wb_control_view		(WorkbookControl const *wbc);
-Workbook     *wb_control_workbook	(WorkbookControl const *wbc);
+Workbook     *wb_control_get_workbook	(WorkbookControl const *wbc);
+GODoc	     *wb_control_get_doc	(WorkbookControl const *wbc);
 Sheet        *wb_control_cur_sheet	(WorkbookControl const *wbc);
 SheetView    *wb_control_cur_sheet_view	(WorkbookControl const *wbc);
 
