@@ -9,7 +9,7 @@
  * (C) 2000-2005 Ximian, Inc.
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "workbook-edit.h"
 
@@ -38,6 +38,7 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <goffice/utils/format-impl.h>
+#include <goffice/utils/go-font.h>
 
 #define GNM_RESPONSE_REMOVE -1000
 
@@ -121,9 +122,9 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 		char const *txt = wbcg_edit_get_display_text (wbcg);
 		GnmStyle const *mstyle = sheet_style_get (sheet, sv->edit_pos.col, sv->edit_pos.row);
 		char const *expr_txt = NULL;
+		GOFormat *fmt = gnm_cell_get_format (sheet_cell_fetch (sheet, sv->edit_pos.col, sv->edit_pos.row));
 
-		/* BE CAREFUL the standard fmts must not NOT include '@' */
-		GnmValue *value = format_match (txt, gnm_style_get_format (mstyle),
+		GnmValue *value = format_match (txt, fmt,
 						workbook_date_conv (sheet->workbook));
 		if (value != NULL)
 			value_release (value);
@@ -141,7 +142,7 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 			parse_pos_init_editpos (&pp, sv);
 			parse_error_init (&perr);
 			texpr = gnm_expr_parse_str (expr_txt,
-				&pp, GNM_EXPR_PARSE_DEFAULT, gnm_expr_conventions_default, &perr);
+				&pp, GNM_EXPR_PARSE_DEFAULT, NULL, &perr);
 			/* Try adding a single extra closing paren to see if it helps */
 			if (texpr == NULL && perr.err != NULL &&
 			    perr.err->code == PERR_MISSING_PAREN_CLOSE) {
@@ -150,7 +151,7 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 				parse_error_init (&tmp_err);
 				texpr = gnm_expr_parse_str (gnm_expr_char_start_p (tmp),
 					&pp, GNM_EXPR_PARSE_DEFAULT,
-					gnm_expr_conventions_default, &tmp_err);
+					NULL, &tmp_err);
 				parse_error_free (&tmp_err);
 
 				if (texpr != NULL)
@@ -214,8 +215,7 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 
 		valid = validation_eval (wbc, mstyle, sheet, &sv->edit_pos, showed_dialog);
 
-		if (free_txt != NULL)
-			g_free (free_txt);
+		g_free (free_txt);
 
 		if (valid != VALIDATION_STATUS_VALID) {
 			result = WBC_EDIT_REJECT;
@@ -284,11 +284,14 @@ wbcg_edit_finish (WorkbookControlGUI *wbcg, WBCEditResult result,
 
 	wb_control_update_action_sensitivity (wbc);
 
-	/* restore focus to original sheet in case things were being selected
-	 * on a different page.  Do no go through the view, rangesel is
-	 * specific to the control.  */
-	wb_control_sheet_focus (wbc, sheet);
-	scg_edit_stop (wbcg_cur_scg (wbcg));	/* Only the edit sheet has an edit cursor */
+	if (!sheet->workbook->during_destruction) {
+		/* restore focus to original sheet in case things were being selected
+		 * on a different page.  Do no go through the view, rangesel is
+		 * specific to the control.  */
+		wb_control_sheet_focus (wbc, sheet);
+		/* Only the edit sheet has an edit cursor */
+		scg_edit_stop (wbcg_cur_scg (wbcg));
+	}
 	wbcg_auto_complete_destroy (wbcg);
 	wb_control_style_feedback (wbc, NULL);	/* in case markup messed with things */
 
@@ -565,10 +568,12 @@ cb_entry_delete_text (GtkEditable    *editable,
 		      WorkbookControlGUI *wbcg)
 {
 	if (wbcg->auto_completing) {
+		SheetControlGUI *scg = wbcg_cur_scg (wbcg);
 		wbcg_auto_complete_destroy (wbcg);
-		SCG_FOREACH_PANE (wbcg_cur_scg (wbcg), pane,
-			if (pane->editor != NULL)
-				foo_canvas_item_request_update (FOO_CANVAS_ITEM (pane->editor)););
+		if (scg)
+			SCG_FOREACH_PANE (scg, pane,
+					  if (pane->editor != NULL)
+					  foo_canvas_item_request_update (FOO_CANVAS_ITEM (pane->editor)););
 	}
 
 	if (wbcg->edit_line.full_content) {
@@ -595,7 +600,7 @@ static void
 wbcg_edit_init_markup (WorkbookControlGUI *wbcg, PangoAttrList *markup)
 {
 	SheetView const *sv  = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
-	const char *text = gtk_entry_get_text (wbcg_get_entry (wbcg));
+	char const *text = gtk_entry_get_text (wbcg_get_entry (wbcg));
 
 	g_return_if_fail (wbcg->edit_line.full_content == NULL);
 
@@ -765,8 +770,8 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	cell = sheet_cell_get (sv->sheet, col, row);
 	if (cell &&
 	    warn_on_text_format &&
-	    go_format_is_text (cell_get_format (cell)) &&
-	    (cell_has_expr (cell) || !VALUE_IS_STRING (cell->value))) {
+	    go_format_is_text (gnm_cell_get_format (cell)) &&
+	    (gnm_cell_has_expr (cell) || !VALUE_IS_STRING (cell->value))) {
 		GtkResponseType res;
 		GtkWidget *check;
 		GtkWidget *align;
@@ -820,19 +825,19 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 	else if (cell != NULL) {
 		gboolean set_text = FALSE;
 
-		if (cell_is_array (cell)) {
+		if (gnm_cell_is_array (cell)) {
 			/* If this is part of an array we need to remove the
 			 * '{' '}' and the size information from the display.
 			 * That is not actually part of the parsable expression.
 			 */
 			set_text = TRUE;
-		} else if (!cell_has_expr (cell) && VALUE_IS_FLOAT (cell->value)) {
-			GOFormat *fmt = cell_get_format (cell);
+		} else if (!gnm_cell_has_expr (cell) && VALUE_IS_FLOAT (cell->value)) {
+			GOFormat *fmt = gnm_cell_get_format (cell);
 			gnm_float f = value_get_as_float (cell->value);
 
 			switch (fmt->family) {
 			case GO_FORMAT_FRACTION:
-				text = cell_get_entered_text (cell);
+				text = gnm_cell_get_entered_text (cell);
 				g_strchug (text);
 				g_strchomp (text);
 				set_text = TRUE;
@@ -840,7 +845,9 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 
 			case GO_FORMAT_PERCENTAGE: {
 				GString *new_str = g_string_new (NULL);
-				gnm_fmt_general_float (new_str, f * 100, -1);
+				gnm_render_general (NULL, new_str, go_format_measure_zero,
+						    go_font_metrics_unit, f * 100,
+						    -1, FALSE);
 				cursor_pos = g_utf8_strlen (new_str->str, -1);
 				g_string_append_c (new_str, '%');
 				text = g_string_free (new_str, FALSE);
@@ -849,17 +856,20 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 			}
 
 			case GO_FORMAT_NUMBER:
+			case GO_FORMAT_SCIENTIFIC:
 			case GO_FORMAT_CURRENCY:
 			case GO_FORMAT_ACCOUNTING: {
 				GString *new_str = g_string_new (NULL);
-				gnm_fmt_general_float (new_str, f, -1);
+				gnm_render_general (NULL, new_str, go_format_measure_zero,
+						    go_font_metrics_unit, f,
+						    -1, FALSE);
 				text = g_string_free (new_str, FALSE);
 				set_text = TRUE;
 				break;
 			}
 
 			case GO_FORMAT_DATE: {
-				GString *fstr = g_string_new (format_month_before_day ()
+				GString *fstr = g_string_new (go_format_month_before_day ()
 							      ? "m/d/yyyy"
 							      : "d/m/yyyy");
 				GOFormat *new_fmt;
@@ -900,7 +910,7 @@ wbcg_edit_start (WorkbookControlGUI *wbcg,
 		}
 
 		if (!text)
-			text = cell_get_entered_text (cell);
+			text = gnm_cell_get_entered_text (cell);
 
 		if (set_text)
 			gtk_entry_set_text (wbcg_get_entry (wbcg), text);
