@@ -1,10 +1,10 @@
 #ifndef GNUMERIC_XML_IO_H
 #define GNUMERIC_XML_IO_H
 
-#include <gdk/gdktypes.h>
-#include "gnumeric.h"
-#include "xml-io-version.h"
-#include "file.h"
+#include <gnumeric.h>
+#include <xml-io-version.h>
+#include <goffice/utils/goffice-utils.h>
+#include <goffice/app/file.h>
 #include <gsf/gsf-libxml.h>
 #include <libxml/tree.h>
 #include <libxml/xmlmemory.h>
@@ -39,34 +39,28 @@ void		 xml_parse_ctx_destroy (XmlParseContext *ctxt);
 
 xmlNodePtr   xml_write_style    (XmlParseContext *ctxt, GnmStyle *style);
 
-xmlChar	   *xml_cellregion_write (WorkbookControl *context,
-				  GnmCellRegion *cr, int *size);
 GnmCellRegion *xml_cellregion_read  (WorkbookControl *context, Sheet *sheet,
-				  guchar *buffer, int length);
+				     guchar const *buffer, int length);
 
-/* Some utility routines for setting attributes or content */
-xmlChar   *xml_node_get_cstr	(xmlNodePtr node, char const *name);
-void	   xml_node_set_cstr	(xmlNodePtr node, char const *name, char const *val);
-gboolean   xml_node_get_bool	(xmlNodePtr node, char const *name, gboolean *val);
-void       xml_node_set_bool	(xmlNodePtr node, char const *name, gboolean val);
-gboolean   xml_node_get_int	(xmlNodePtr node, char const *name, int *val);
-void       xml_node_set_int	(xmlNodePtr node, char const *name, int val);
-gboolean   xml_node_get_double	(xmlNodePtr node, char const *name, double *val);
-void       xml_node_set_double	(xmlNodePtr node, char const *name, double val, int precision);
-GnmColor*xml_node_get_color	(xmlNodePtr node, char const *name);
+GnmColor  *xml_node_get_color	(xmlNodePtr node, char const *name);
 void       xml_node_set_color	(xmlNodePtr node, char const *name, GnmColor const *color);
 
 xmlNodePtr   xml_write_style    (XmlParseContext *ctxt, GnmStyle *style);
 GnmStyle      *xml_read_style     (XmlParseContext *ctxt, xmlNodePtr tree);
 
 void      xml_init (void);
-
-xmlNode *e_xml_get_child_by_name	 (xmlNode const *tree, char const *name);
-xmlNode *e_xml_get_child_by_name_no_lang (xmlNode const *tree, char const *name);
-xmlNode *e_xml_get_child_by_name_by_lang (xmlNode const *tree, char const *name);
-
 /* Gnumeric specific SAX utilities */
 void gnm_xml_out_add_color   (GsfXMLOut *o, char const *id, GnmColor const *c);
+void gnm_xml_out_add_gocolor (GsfXMLOut *o, char const *id, GOColor c);
 void gnm_xml_out_add_cellpos (GsfXMLOut *o, char const *id, GnmCellPos const *p);
 
+/* Gnumeric specific SAX import */
+gboolean gnm_xml_attr_int     (xmlChar const * const *attrs,
+			       char const *name, int * res);
+gboolean gnm_xml_attr_double  (xmlChar const * const *attrs,
+			       char const *name, double * res);
+
+SheetObject *gnm_xml_in_cur_obj   (GsfXMLIn const *xin);
+Sheet	    *gnm_xml_in_cur_sheet (GsfXMLIn const *xin);
+
 #endif /* GNUMERIC_XML_IO_H */
